<?php

namespace Crm\School\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Crm\School\Events\GalleryAction as GalleryActionEvent;
use Crm\School\Notifications\GalleryAction as GalleryActionNotification;
use Litepie\Actions\Concerns\AsAction;

class GalleryAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the GalleryActionEvent.
     *
     * @param   GalleryActionEvent  $event
     * @return mixed
     */
    public function handle(GalleryActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $gallery.
     *
     * @param   GalleryActionEvent  $event
     * @return void
     */
    public function create(GalleryActionEvent $event)
    {
        $client = $event->gallery->client;
        Notification::send($client, new GalleryActionNotification($event));
    }

    /**
     * Handle the GalleryActionEvent as a listener.
     *
     * @param   GalleryActionEvent  $event
     * @return mixed
     */
    public function asListener(GalleryActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   GalleryActionEvent  $event
     * @return bool
     */
    private function isAllowed(GalleryActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
