<?php

namespace Crm\School\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Crm\School\Events\GalleryWorkflow as GalleryWorkflowEvent;
use Crm\School\Notifications\GalleryWorkflow as GalleryWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class GalleryWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(GalleryWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $gallery is submitted.
     *
     * @param GalleryWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(GalleryWorkflowEvent $event)
    {
        $client = $event->gallery->client;
        Notification::send($client, new GalleryWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $gallery is published.
     *
     * @param GalleryWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(GalleryWorkflowEvent $event)
    {
        $client = $event->gallery->client;
        Notification::send($client, new GalleryWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $gallery is approved.
     *
     * @param GalleryWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(GalleryWorkflowEvent $event)
    {
        $client = $event->gallery->client;
        Notification::send($client, new GalleryWorkflowNotification($event));
    }

    /**
     * Handles the $gallery workflow event as a listener.
     *
     * @param GalleryWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(GalleryWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
