<?php

namespace Crm\School\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Crm\School\Models\Slider;

class SliderPolicy
{


    /**
     * Determine if the given user can view the slider.
     *
     * @param Authenticatable $user
     * @param Slider $slider
     *
     * @return bool
     */
    public function view(Authenticatable $user, Slider $slider)
    {
        if ($authUser->canDo('school.slider.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $slider->is_owner;
    }

    /**
     * Determine if the given user can create a slider.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('school.slider.create');
    }

    /**
     * Determine if the given user can update the given slider.
     *
     * @param Authenticatable $user
     * @param Slider $slider
     *
     * @return bool
     */
    public function update(Authenticatable $user, Slider $slider)
    {
        if ($user->canDo('school.slider.edit') && $user->isAdmin()) {
            return true;
        }

        return $slider->is_owner;
    }

    /**
     * Determine if the given user can delete the given slider.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Slider $slider)
    {
        return $slider->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
